from django.contrib import auth
from django.urls import path

from . import views

urlpatterns = [
    path(
        "",
        views.MapsView.as_view(),
        name="maps",
    ),
    path(
        "issues/",
        views.IssueListView.as_view(),
        name="issues",
    ),
    path(
        "room/<slug:slug>/map",
        views.RoomMapView.as_view(),
        name="room_map",
    ),
    path(
        "sessions/",
        views.SessionListView.as_view(),
        name="sessions",
    ),
    path(
        "user/<str:username>/sessions/history",
        views.UserSessionHistoryView.as_view(),
        name="user_session_history",
    ),
    path(
        "user/<str:username>",
        views.UserProfileView.as_view(),
        name="user_profile",
    ),
    path(
        "user/<str:username>/issues",
        views.IssueListView.as_view(),
        name="user_issues",
    ),
    path(
        "login",
        auth.views.LoginView.as_view(),
        name="login",
    ),
    path(
        "logout",
        auth.views.LogoutView.as_view(),
        name="logout",
    ),
    path(
        "workstations/<int:pk>",
        views.WorkstationDetailView.as_view(),
        name="workstation_detail",
    ),
    path(
        "workstations/<int:workstation_pk>/issue/create",
        views.WorkstationIssueCreateFormView.as_view(),
        name="workstation_issue_create",
    ),
    path(
        "workstations/<int:workstation_pk>/issue/<int:pk>/update",
        views.WorkstationIssueUpdateFormView.as_view(),
        name="workstation_issue_update",
    ),
    path(
        "workstations/<int:workstation_pk>/issue/<int:pk>/confirm",
        views.WorkstationIssueConfirmView.as_view(),
        name="workstation_issue_confirm",
    ),
    path(
        "workstations/<int:workstation_pk>/issue/<int:pk>/reject",
        views.WorkstationIssueRejectView.as_view(),
        name="workstation_issue_reject",
    ),
    path(
        "workstations/<int:workstation_pk>/issue/<int:pk>/resolve",
        views.WorkstationIssueResolveView.as_view(),
        name="workstation_issue_resolve",
    ),
]
