# Generated by Django 3.2.7 on 2021-09-21 21:52

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Image",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("title", models.CharField(max_length=256, unique=True)),
                ("name", models.CharField(blank=True, max_length=256)),
                ("kernel", models.URLField()),
                ("initrd", models.URLField(blank=True)),
                ("cmdline", models.CharField(blank=True, max_length=256)),
            ],
            options={
                "ordering": ("name",),
            },
        ),
        migrations.CreateModel(
            name="Item",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("priority", models.SmallIntegerField(blank=True, default=0)),
                ("label", models.CharField(max_length=80)),
                (
                    "type",
                    models.CharField(
                        choices=[
                            ("submenu", "Submenu"),
                            ("img", "Image"),
                            ("uri", "URI"),
                            ("custom", "Custom script"),
                            ("separator", "Separator"),
                        ],
                        max_length=10,
                    ),
                ),
                ("key", models.CharField(blank=True, max_length=4)),
                ("extra_cmdline", models.CharField(blank=True, max_length=256)),
                ("uri", models.URLField(blank=True)),
                ("script", models.TextField(blank=True)),
            ],
            options={
                "ordering": (
                    "category__priority",
                    "category__label",
                    "priority",
                    "label",
                ),
            },
        ),
        migrations.CreateModel(
            name="ItemCategory",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("title", models.CharField(max_length=256, unique=True)),
                ("label", models.CharField(blank=True, max_length=80)),
                ("priority", models.SmallIntegerField(blank=True, default=0)),
            ],
            options={
                "verbose_name_plural": "item categories",
                "ordering": ("priority", "label"),
            },
        ),
        migrations.CreateModel(
            name="ItemGroup",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("title", models.CharField(blank=True, max_length=80)),
                (
                    "categories",
                    models.ManyToManyField(blank=True, to="pxe.ItemCategory"),
                ),
                ("items", models.ManyToManyField(blank=True, to="pxe.Item")),
            ],
        ),
        migrations.CreateModel(
            name="MatchingGroup",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=256, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name="NetworkMatcher",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("network_address", models.GenericIPAddressField(unpack_ipv4=True)),
                ("prefix_length", models.PositiveSmallIntegerField()),
                (
                    "group",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="pxe.matchinggroup",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="Menu",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("title", models.CharField(max_length=80)),
                (
                    "timeout",
                    models.PositiveIntegerField(
                        blank=True, help_text="in second", null=True
                    ),
                ),
                (
                    "default_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="menu_default",
                        to="pxe.item",
                    ),
                ),
                ("item_groups", models.ManyToManyField(blank=True, to="pxe.ItemGroup")),
                ("items", models.ManyToManyField(blank=True, to="pxe.Item")),
            ],
            options={
                "ordering": ("title",),
            },
        ),
        migrations.AddField(
            model_name="matchinggroup",
            name="menu",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="pxe.menu",
            ),
        ),
        migrations.CreateModel(
            name="MacAddressMatcher",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("mac_address", models.CharField(max_length=256)),
                (
                    "group",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="pxe.matchinggroup",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.AddField(
            model_name="item",
            name="category",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="pxe.itemcategory",
            ),
        ),
        migrations.AddField(
            model_name="item",
            name="image",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="pxe.image",
            ),
        ),
        migrations.AddField(
            model_name="item",
            name="submenu",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="pxe.menu",
            ),
        ),
        migrations.CreateModel(
            name="IPAddressMatcher",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("ip_address", models.GenericIPAddressField(unpack_ipv4=True)),
                (
                    "group",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="pxe.matchinggroup",
                    ),
                ),
            ],
            options={
                "verbose_name": "IP address matcher",
            },
        ),
    ]
